function opp = eternity_grid_line_edges ( )

%*****************************************************************************80
%
%% eternity_grid_line_edges() indexes edge nodes that end Eternity grid lines.
%
%  Discussion:
%
%    The Eternity grid include 12 sides or edges, and 180 edge nodes.
%    Each edge comprises 15 or 17 nodes, two of which are shared with 
%    a neighboring edge.
%
%  Licensing:
%
%    This code is distributed under the GNU LGPL license.
%
%  Modified:
%
%    22 December 2020
%
%  Author:
%
%    John Burkardt
%
%  Output:
%
%    integer OPP(180,6): OPP(I,1:6) are the indices of the six edge 
%    nodes that are opposite to edge node I in the 0/180, 60/240, 
%    120/300, 90/270, 150/330, 210/30 degree directions.
%
  opp = zeros(180,6);

  opp = [ ...
    91,   31,  151,   -1,   61,  121; ...
    -1,   -1,   -1,   -1,   60,  120; ...
    89,   -1,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,   -1,   58,  118; ...
    87,   27,  147,   -1,   57,  117; ...
    -1,   -1,   -1,   -1,   56,  116; ...
    85,   -1,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,   -1,   54,  114; ...
    83,   23,  143,  173,   53,  113; ...
    -1,   -1,   -1,   -1,   -1,  112; ...
    81,   -1,  141,  171,   51,  111; ...
    -1,   -1,   -1,   -1,   -1,  110; ...
    79,   -1,  139,  169,   49,  109; ...
    -1,   -1,   -1,   -1,   -1,  108; ...
    77,   -1,  137,  167,   47,  107; ...
    -1,   -1,   -1,   -1,   -1,  106; ...
    75,   -1,  135,  165,   45,  105; ...
    -1,   -1,   -1,   -1,   -1,  104; ...
    73,   -1,  133,  163,   43,  103; ...
    -1,   -1,   -1,   -1,   -1,  102; ...
    71,   -1,  131,  161,   41,  101; ...
    -1,   -1,   -1,   -1,   -1,  100; ...
    69,    9,  129,  159,   39,   99; ...
    -1,   -1,   -1,  158,   -1,   98; ...
    -1,   -1,  127,   -1,   -1,   -1; ...
    -1,   -1,   -1,  156,   -1,   96; ...
    65,    5,  125,  155,   -1,   95; ...
    -1,   -1,   -1,  154,   -1,   94; ...
    -1,   -1,  123,   -1,   -1,   -1; ...
    -1,   -1,   -1,  152,   -1,   92; ...
    61,    1,  121,  151,   -1,   91; ...
    -1,   -1,   -1,  150,   -1,   90; ...
    -1,   -1,  119,   -1,   -1,   -1; ...
    -1,   -1,   -1,  148,   -1,   88; ...
    57,  177,  117,  147,   -1,   87; ...
    -1,   -1,   -1,  146,   -1,   86; ...
    -1,   -1,  115,   -1,   -1,   -1; ...
    -1,   -1,   -1,  144,   -1,   84; ...
    53,  173,  113,  143,   23,   83; ...
    -1,   -1,   -1,  142,   -1,   -1; ...
    -1,  171,  111,  141,   21,   81; ...
    -1,   -1,   -1,  140,   -1,   -1; ...
    -1,  169,  109,  139,   19,   79; ...
    -1,   -1,   -1,  138,   -1,   -1; ...
    -1,  167,  107,  137,   17,   77; ...
    -1,   -1,   -1,  136,   -1,   -1; ...
    -1,  165,  105,  135,   15,   75; ...
    -1,   -1,   -1,  134,   -1,   -1; ...
    -1,  163,  103,  133,   13,   73; ...
    -1,   -1,   -1,  132,   -1,   -1; ...
    -1,  161,  101,  131,   11,   71; ...
    -1,   -1,   -1,  130,   -1,   -1; ...
    39,  159,   99,  129,    9,   69; ...
    -1,   -1,   -1,  128,    8,   -1; ...
    -1,  157,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,  126,    6,   -1; ...
    35,  155,   95,  125,    5,   -1; ...
    -1,   -1,   -1,  124,    4,   -1; ...
    -1,  153,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,  122,    2,   -1; ...
    31,  151,   91,  121,    1,   -1; ...
    -1,   -1,   -1,  120,  180,   -1; ...
    -1,  149,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,  118,  178,   -1; ...
    27,  147,   87,  117,  177,   -1; ...
    -1,   -1,   -1,  116,  176,   -1; ...
    -1,  145,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,  114,  174,   -1; ...
    23,  143,   83,  113,  173,   53; ...
    -1,   -1,   -1,   -1,  172,   -1; ...
    21,  141,   -1,  111,  171,   51; ...
    -1,   -1,   -1,   -1,  170,   -1; ...
    19,  139,   -1,  109,  169,   49; ...
    -1,   -1,   -1,   -1,  168,   -1; ...
    17,  137,   -1,  107,  167,   47; ...
    -1,   -1,   -1,   -1,  166,   -1; ...
    15,  135,   -1,  105,  165,   45; ...
    -1,   -1,   -1,   -1,  164,   -1; ...
    13,  133,   -1,  103,  163,   43; ...
    -1,   -1,   -1,   -1,  162,   -1; ...
    11,  131,   -1,  101,  161,   41; ...
    -1,   -1,   -1,   -1,  160,   -1; ...
     9,  129,   69,   99,  159,   39; ...
    -1,   -1,   -1,   -1,  158,   38; ...
     7,   -1,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,   -1,  156,   36; ...
     5,  125,   65,   -1,  155,   35; ...
    -1,   -1,   -1,   -1,  154,   34; ...
     3,   -1,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,   -1,  152,   32; ...
     1,  121,   61,   -1,  151,   31; ...
    -1,   -1,   -1,   -1,  150,   30; ...
   179,   -1,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,   -1,  148,   28; ...
   177,  117,   57,   -1,  147,   27; ...
    -1,   -1,   -1,   -1,  146,   26; ...
   175,   -1,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,   -1,  144,   24; ...
   173,  113,   53,   83,  143,   23; ...
    -1,   -1,   -1,   -1,   -1,   22; ...
   171,   -1,   51,   81,  141,   21; ...
    -1,   -1,   -1,   -1,   -1,   20; ...
   169,   -1,   49,   79,  139,   19; ...
    -1,   -1,   -1,   -1,   -1,   18; ...
   167,   -1,   47,   77,  137,   17; ...
    -1,   -1,   -1,   -1,   -1,   16; ...
   165,   -1,   45,   75,  135,   15; ...
    -1,   -1,   -1,   -1,   -1,   14; ...
   163,   -1,   43,   73,  133,   13; ...
    -1,   -1,   -1,   -1,   -1,   12; ...
   161,   -1,   41,   71,  131,   11; ...
    -1,   -1,   -1,   -1,   -1,   10; ...
   159,   99,   39,   69,  129,    9; ...
    -1,   -1,   -1,   68,   -1,    8; ...
    -1,   -1,   37,   -1,   -1,   -1; ...
    -1,   -1,   -1,   66,   -1,    6; ...
   155,   95,   35,   65,   -1,    5; ...
    -1,   -1,   -1,   64,   -1,    4; ...
    -1,   -1,   33,   -1,   -1,   -1; ...
    -1,   -1,   -1,   62,   -1,    2; ...
   151,   91,   31,   61,   -1,    1; ...
    -1,   -1,   -1,   60,   -1,  180; ...
    -1,   -1,   29,   -1,   -1,   -1; ...
    -1,   -1,   -1,   58,   -1,  178; ...
   147,   87,   27,   57,   -1,  177; ...
    -1,   -1,   -1,   56,   -1,  176; ...
    -1,   -1,   25,   -1,   -1,   -1; ...
    -1,   -1,   -1,   54,   -1,  174; ...
   143,   83,   23,   53,  113,  173; ...
    -1,   -1,   -1,   52,   -1,   -1; ...
    -1,   81,   21,   51,  111,  171; ...
    -1,   -1,   -1,   50,   -1,   -1; ...
    -1,   79,   19,   49,  109,  169; ...
    -1,   -1,   -1,   48,   -1,   -1; ...
    -1,   77,   17,   47,  107,  167; ...
    -1,   -1,   -1,   46,   -1,   -1; ...
    -1,   75,   15,   45,  105,  165; ...
    -1,   -1,   -1,   44,   -1,   -1; ...
    -1,   73,   13,   43,  103,  163; ...
    -1,   -1,   -1,   42,   -1,   -1; ...
    -1,   71,   11,   41,  101,  161; ...
    -1,   -1,   -1,   40,   -1,   -1; ...
   129,   69,    9,   39,   99,  159; ...
    -1,   -1,   -1,   38,   98,   -1; ...
    -1,   67,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,   36,   96,   -1; ...
   125,   65,    5,   35,   95,   -1; ...
    -1,   -1,   -1,   34,   94,   -1; ...
    -1,   63,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,   32,   92,   -1; ...
   121,   61,    1,   31,   91,   -1; ...
    -1,   -1,   -1,   30,   90,   -1; ...
    -1,   59,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,   28,   88,   -1; ...
   117,   57,  177,   27,   87,   -1; ...
    -1,   -1,   -1,   26,   86,   -1; ...
    -1,   55,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,   24,   84,   -1; ...
   113,   53,  173,   23,   83,  143; ...
    -1,   -1,   -1,   -1,   82,   -1; ...
   111,   51,   -1,   21,   81,  141; ...
    -1,   -1,   -1,   -1,   80,   -1; ...
   109,   49,   -1,   19,   79,  139; ...
    -1,   -1,   -1,   -1,   78,   -1; ...
   107,   47,   -1,   17,   77,  137; ...
    -1,   -1,   -1,   -1,   76,   -1; ...
   105,   45,   -1,   15,   75,  135; ...
    -1,   -1,   -1,   -1,   74,   -1; ...
   103,   43,   -1,   13,   73,  133; ...
    -1,   -1,   -1,   -1,   72,   -1; ...
   101,   41,   -1,   11,   71,  131; ...
    -1,   -1,   -1,   -1,   70,   -1; ...
    99,   39,  159,    9,   69,  129; ...
    -1,   -1,   -1,   -1,   68,  128; ...
    97,   -1,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,   -1,   66,  126; ...
    95,   35,  155,   -1,   65,  125; ...
    -1,   -1,   -1,   -1,   64,  124; ...
    93,   -1,   -1,   -1,   -1,   -1; ...
    -1,   -1,   -1,   -1,   62,  122 ];

  return
end

